@@ -396,7 +396,7 @@ class Account(object):
                 ]
                 data.append(row)
 
-        functions_df = pd.DataFrame(columns=dataframe_columns)
+        functions_df = pd.DataFrame(data, columns=dataframe_columns)
         return functions_df
 
     def lambda_get_metrics_list(self, namespace="AWS/Lambda"):
@@ -428,7 +428,7 @@ class Account(object):
                     data.append(row)
             # break
         metrics_df = pd.DataFrame(row, columns=dataframe_columns)
-        print(metrics_df.shape)
+        return metrics_df
 
     def lambda_get_invocations(self, lambda_name, start_date=None, end_date=None):
         sdate = (
